@@ -27,9 +27,10 @@ logger = logging.getLogger(__name__)
 class CodeShouldBe200(NeteaseIOError):
     def __init__(self, data):
         self._code = data['code']
+        self._data = data
 
     def __str__(self):
-        return 'json code field should be 200, got {}'.format(self._code)
+        return f'json code field should be 200, got {self._code}. data: {self._data}'
 
 
 class API(object):
@@ -321,9 +322,11 @@ class API(object):
         action = uri + '/song/detail/?id=' + str(music_id) + '&ids=[' +\
             str(music_id) + ']'
         data = self.request('GET', action)
-        if data['songs']:
-            return data['songs'][0]
-        return
+        if data['code'] == 200:
+            if data['songs']:
+                return data['songs'][0]
+            return
+        raise CodeShouldBe200(data)
 
     def weapi_songs_url(self, music_ids, bitrate=320000):
         """
@@ -453,7 +456,9 @@ class API(object):
         }
         """
         # tv 表示翻译。-1：表示要翻译，1：不要
-        url = uri + '/song/lyric?' + 'id=' + str(mid) + '&lv=1&kv=1&tv=-1'
+        # lv 为 1 时，对于纯音乐，API 返回的歌词为空
+        # lv 为 -1 时，纯音乐返回的歌词是：纯音乐，请欣赏
+        url = uri + '/song/lyric?' + 'id=' + str(mid) + '&lv=-1&kv=1&tv=-1'
         return self.request('GET', url)
 
     def get_similar_song(self, mid, offset=0, limit=10):
